@@ -151,8 +151,9 @@
 #' @rdname sadists
 #' @docType package
 #' @title Some Additional Distributions
+#' @aliases sadists-package
 #' @keywords package
-NULL
+"_PACKAGE"
 
 #' @title News for package 'sadists'
 #'
@@ -162,6 +163,11 @@ NULL
 #'
 #' \newcommand{\sadists}{\href{https://github.com/shabbychef/sadists}}
 #'
+#' @section \sadists{} Version 0.2.5 (2023-08-20):
+#' \itemize{
+#' \item CRAN emergency release.
+#' }
+#'
 #' @section \sadists{} Version 0.2.4 (2020-06-23):
 #' \itemize{
 #' \item CRAN emergency release.
